aboutsummaryrefslogtreecommitdiff
path: root/src/logging/timer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/logging/timer.h')
-rw-r--r--src/logging/timer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/logging/timer.h b/src/logging/timer.h
index 993ba99c25..0a6813cdd5 100644
--- a/src/logging/timer.h
+++ b/src/logging/timer.h
@@ -55,7 +55,7 @@ public:
if (m_log_category == BCLog::LogFlags::ALL) {
LogPrintf("%s\n", full_msg);
} else {
- LogPrint(m_log_category, "%s\n", full_msg);
+ LogDebug(m_log_category, "%s\n", full_msg);
}
}
@@ -87,7 +87,7 @@ private:
//! A descriptive message of what is being timed.
const std::string m_title;
//! Forwarded on to LogPrint if specified - has the effect of only
//! outputting the timing log when a particular debug= category is specified.
const BCLog::LogFlags m_log_category;
@@ -87,7 +87,7 @@ private:
//! A descriptive message of what is being timed.
const std::string m_title;
- //! Forwarded on to LogPrint if specified - has the effect of only
+ //! Forwarded on to LogDebug if specified - has the effect of only
//! outputting the timing log when a particular debug= category is specified.
const BCLog::LogFlags m_log_category;